
<!---
FrozenIsBool True
-->

##Example

Let's create some methods in a class that kind of call/hook each other.
Notice that the instance calling the method is specified with all the attribute key str ending with 'TagStr' in order to identify them.